@@ -1,12 +1,10 @@
 package Promises6;
-use Evo::Base -strict;
+use Evo -modern;
 use Exporter 'import';
 use Promises6::Util ':all';
 use Promises6::Evo::Builder;
-use Evo::Manager;
-use Evo;
 
-our $VERSION = '0.007';    # VERSION
+our $VERSION = '0.008';    # VERSION
 my @DSL = qw(when_ok when_rejected when_progress promise then);
 our @EXPORT_OK = (@DSL, qw(deferred resolved rejected all race));
 our %EXPORT_TAGS = (all => \@EXPORT_OK, dsl => \@DSL);
@@ -14,7 +12,8 @@ sub deferred { Promises6::Evo::Builder->singleton->deferred() }
 
 # dsl
 sub then {
-  Evo::dsl_stash->{'promise'} = Evo::dsl_stash('promise')->then(@_);
+  my $dsl = Evo::dep_single 'Evo::Dsl';
+  $dsl->stash->{'promise'} = $dsl->stash->{'promise'}->then(@_);
 }
 sub when_ok : prototype(&)       { then(shift, undef, undef) }
 sub when_rejected : prototype(&) { then(undef, shift, undef) }
@@ -72,12 +71,13 @@ sub promise : prototype(&) {
   my $notify  = sub { $d->notify($_[0]) };
 
   my $promise = $d->promise;
-  Evo::dsl_call(
+  my $dsl     = Evo::dep_single('Evo::Dsl');
+  $dsl->call(
     {promise => $d->promise},
     $resolve, $reject, $notify,
     sub {
       $cb->($resolve, $reject, $notify);
-      $promise = Evo::dsl_stash('promise');
+      $promise = $dsl->stash('promise');
     }
   );
 
@@ -111,11 +111,11 @@ Promises6 - Promises6 - Promises/A+ with DSL, ES6 syntax and progress notificati
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
-  use Evo::Base -strict;
+  use Evo;
   use Promises6 ':all';
   use Mojo::IOLoop;
   use Mojo::UserAgent;
