@@ -1,9 +1,7 @@
 package Promises6::Evo::Builder;
-use Evo::Base 'Promises6::Builder';
-use Evo::Manager;
+use Evo 'Promises6::Builder';
 
 # run always in 1 depth
-sub train { state $train = Evo::Manager->singleton->build_train }
 
 has deferred_class => sub {
   require Promises6::Evo::Deferred;
@@ -26,7 +24,7 @@ Promises6::Evo::Builder - A builder
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 ATTRIBUTES
 
