@@ -1,10 +1,8 @@
 package Promises6::Evo::Deferred;
-use Evo::Base 'Promises6::Deferred';
-use Evo;
+use Evo 'Promises6::Deferred', -modern;
 
 sub send_msg($self, @args) {
-  my $train = $self->builder->train;
-  Evo::asap { $self->SUPER::send_msg(@args) };
+  Evo::dep_single('Evo::Flow')->asap(sub { $self->SUPER::send_msg(@args) });
 }
 
 1;
@@ -23,7 +21,7 @@ Promises6::Evo::Deferred - A deferred class
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 METHODS
 
