@@ -1,5 +1,5 @@
 package Promises6::Listener;
-use Evo::Base -base;
+use Evo -class, -modern;
 use Promises6::Util 'PROGRESS';
 
 has [qw(deferred builder)];
@@ -47,11 +47,11 @@ Promises6::Listener - A listener.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
-  use Evo::Base -strict;
+  use Evo;
   use Promises6::Builder;
 
   my $bldr     = Promises6::Builder->new();
