@@ -1,5 +1,5 @@
 package Promises6::Resolver;
-use Evo::Base -base;
+use Evo -class, -modern;
 use Promises6::Util ':all';
 use Scalar::Util;
 use Hash::Util::FieldHash 'fieldhash';
@@ -96,7 +96,7 @@ Promises6::Resolver
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 ATTRIBUTES
 
